@@ -1,10 +1,11 @@
 """Restructured text view to export content of a tracker instance
 
 :organization: Logilab
-:copyright: 2007-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2007-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
+_ = unicode
 
 from logilab.common.textutils import normalize_text
 
@@ -14,8 +15,6 @@ from cubicweb.selectors import (is_instance, match_search_state, one_line_rset,
 from cubicweb.entity import _marker
 from cubicweb.web import action
 
-from cubes.tracker.entities import attr_tuple
-
 class ReSTItemView(EntityView):
     __abstract__ = True
     __regid__ = 'docitem'
@@ -44,9 +43,9 @@ class ReSTItemView(EntityView):
         if value:
             self.w(u':%s: %s\n' % (attr, value))
 
-    def cell_call(self, row, col):
+    def entity_call(self, entity):
         """ReST view for Project entities"""
-        entity = self.cw_rset.complete_entity(row, col)
+        entity.complete()
         self._title(u'%s %s' % (entity.dc_type(), entity.dc_title()))
         self.render_attributes(entity)
         self.w(u'\n')
@@ -78,9 +77,7 @@ class ProjectDocumentItemView(ReSTItemView):
     text_fields = ['summary', 'description']
 
     def render_child(self, entity):
-        # version (sort by ascending version.num)
-        for ver in reversed(entity.reverse_version_of):
-            ver.view('docitem', w=self.w)
+        self.wview('docitem', entity.related('version_of', 'object'), 'null')
 
 
 class VersionDocumentItemView(ReSTItemView):
@@ -101,9 +98,7 @@ class VersionDocumentItemView(ReSTItemView):
             self.field(entity, 'prevision_date')
 
     def render_child(self, entity):
-        rset = self._cw.execute(*attr_tuple(entity, 'tickets_rql'))
-        for ticket in rset.entities():
-            ticket.view('docitem', w=self.w)
+        self.wview('docitem', entity.related('done_in', 'object'), 'null')
 
 
 class TicketDocumentItemView(ReSTItemView):
